audmetric
=========

.. automodule:: audmetric

.. autosummary::
    :toctree:
    :nosignatures:

    accuracy
    concordance_cc
    confusion_matrix
    detection_error_tradeoff
    edit_distance
    equal_error_rate
    event_error_rate
    linkability
    mean_absolute_error
    mean_squared_error
    pearson_cc
    fscore_per_class
    precision_per_class
    recall_per_class
    unweighted_average_bias
    unweighted_average_fscore
    unweighted_average_precision
    unweighted_average_recall
    weighted_confusion_error
    word_error_rate
